@@ -115,9 +115,8 @@ class PipedashWorker:
 
             # Declaring queue
             queue = await self.channel.declare_queue(
-                "",
-                durable=True,
-                exclusive=True
+                "pipedash_worker_queue",
+                durable=True
             )
 
             src_exchange = await self.channel.declare_exchange(
